@@ -82,7 +82,7 @@ def _get_LF_output_fmt(short_name, filetype='snapshot'):
         ret = next(item for item in _LFoutput_fmt if item['short_name'] == short_name and item['file'] in [filetype, 'all'])
     except:
         warnings.warn('Item {} not in known output formats for filetype {}'.format(short_name, filetype))
-        ret = {'file': 'unknown', 'short_name': short_name, 'long time': short_name.replace('_', ' '), 'symbol': '', 'units': '', 'dtype': '', 'infile': True, },
+        ret = {'file': 'unknown', 'short_name': short_name, 'long time': short_name.replace('_', ' '), 'symbol': '', 'units': '', 'dtype': '', 'infile': True, }
     return ret
 
 class LaharFlowData(object):
